From 3954ea3cea46a60ab7c09862f3167c672367adcf Mon Sep 17 00:00:00 2001
From: Benjamin Auder <benjamin.auder@somewhere>
Date: Sat, 14 Jan 2017 18:51:47 +0100
Subject: [PATCH] clarify main/classif task

---
 old_C_code/stage1/src/main.c | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)

diff --git a/old_C_code/stage1/src/main.c b/old_C_code/stage1/src/main.c
index 9800778..d1f7965 100644
--- a/old_C_code/stage1/src/main.c
+++ b/old_C_code/stage1/src/main.c
@@ -117,7 +117,7 @@ int cluster_main(int argc, char **argv)
 		nbClusters = nbSeriesInChunk;
 
 	double idealNbSeriesInChunk = 0.0; //unused if randomize == TRUE
-	if (!randomize) 
+	if (!randomize)
 	{
 		// Adjust nbSeriesInChunk to avoid small remainders.
 		// Each node should have at least nbSeriesInChunk (as given to the function).
@@ -154,6 +154,7 @@ int cluster_main(int argc, char **argv)
 }
 
 //main classification task (using clustering result)
+//NOTE: ifileName == courbes à classer (?!)
 int classif_main(int argc, char** argv)
 {
 	const char* ifileName = argv[1];
@@ -221,6 +222,7 @@ int classif_main(int argc, char** argv)
 
 	uint32_t smallestNonProcessedIndex = 0;
 	double DISTOR = 0.0;
+	FILE* labelsFile = fopen("LABELS", "w");
 	while (smallestNonProcessedIndex < nbSeries)
 	{
 		uint32_t lowerBound = smallestNonProcessedIndex;
@@ -230,23 +232,24 @@ int classif_main(int argc, char** argv)
 		for (uint32_t i=0; i<upperBound-lowerBound; i++)
 			ranks[i] = lowerBound + i;
 		PowerCurve* data = deserialize(ifileName, NULL, ranks, upperBound-lowerBound);
-		uint32_t* labels = get_class(data, upperBound-lowerBound, medoids, nbClusters, 
+		uint32_t* labels = get_class(data, upperBound-lowerBound, medoids, nbClusters,
 			nbValues, p_for_dissims, &DISTOR);
 		// send labels to standard output
 		for (uint32_t i=0; i<upperBound-lowerBound; i++)
 		{
 			free(data[i].values);
-			fprintf(stdout, "%u\n",labels[i]);
+			fprintf(labelsFile, "%u\n",labels[i]);
 		}
 		free(data);
 		free(labels);
 		smallestNonProcessedIndex += (upperBound-lowerBound);
 	}
+	fclose(labelsFile);
 	for (uint32_t i=0; i<nbClusters; i++)
 		free(medoids[i].values);
 	free(medoids);
 	free(ranks);
-	fprintf(stderr, "DISTOR = %g\n",DISTOR);
+	fprintf(stdout, "DISTOR = %g\n",DISTOR);
 	return 0;
 }
 
@@ -230,23 +232,24 @@ int classif_main(int argc, char** argv)
 			nbValues, p_for_dissims, &DISTOR);
-		// send labels to standard output
+		// send labels to LABELS file
 		for (uint32_t i=0; i<upperBound-lowerBound; i++)
 		{
-- 
2.44.0